@@ -119,10 +119,10 @@ def activate_line(x, y, z, command, tile_type=""):
 
 		if switch2 == "hp":
 			g.hp = g.hp + int(set_to)
-			if g.hp >= g.maxhp: g.hp = g.maxhp
+			if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
 		elif switch2 == "ep":
 			g.ep = g.ep + int(set_to)
-			if g.ep >= g.maxep: g.ep = g.maxep
+			if g.ep >= g.adj_maxep: g.ep = g.adj_maxep
 			if g.ep < 0: g.ep = 0
 		elif switch2 == "maxhp":
 			g.maxhp = g.maxhp + int(set_to)
@@ -151,6 +151,7 @@ def activate_line(x, y, z, command, tile_type=""):
 			if 1 > g.skillpoints: g.skillpoints = 0
 		else:
 			print "Unknown stat: " + switch2
+		main.recalc_stats()
 		if set_to == 0: return_num = 0
 		else: return_num = 1
 
@@ -339,13 +340,13 @@ def activate_line(x, y, z, command, tile_type=""):
 		elif switch2 == "ep":
 			return_num = g.ep
 		elif switch2 == "maxhp":
-			return_num = g.maxhp
+			return_num = g.adj_maxhp
 		elif switch2 == "maxep":
-			return_num = g.maxep
+			return_num = g.adj_maxep
 		elif switch2 == "attack":
-			return_num = g.attack
+			return_num = g.adj_attack
 		elif switch2 == "defense":
-			return_num = g.defense
+			return_num = g.adj_defense
 		elif switch2 == "gold":
 			return_num = g.gold
 		elif switch2 == "exp":
