@@ -191,7 +191,7 @@ def useitem():
 		main.print_message("You are healed for " +
 					str(g.item.item[item_value].quality) + " health.")
 		g.item.drop_inv_item(g.item.find_inv_item(item_value))
-		if g.hp >= g.maxhp: g.hp = g.maxhp
+		if g.hp >= g.adj_maxhp: g.hp = g.adj_maxhp
 		attack_player()
 
 	#if item is explosive
@@ -675,16 +675,16 @@ def begin(mon_index_input):
 
 
 	#bindings
-	main.window_main.bind("a", attack)
-	main.window_main.bind("<Escape>", key_handler_esc)
-	main.window_main.bind("<Return>", key_handler_return)
-	main.window_main.bind("<Up>", key_handler_up)
-	main.window_main.bind("<Down>", key_handler_down)
-	main.window_main.bind("<Left>", key_handler_left)
-	main.window_main.bind("<Right>", key_handler_right)
-	main.window_main.bind("i", key_handler)
-	main.window_main.bind("s", key_handler)
-	main.window_main.bind("q", key_handler)
+	main.window_main.bind(g.binding_attack, attack)
+	main.window_main.bind(g.binding_cancel, key_handler_esc)
+	main.window_main.bind(g.binding_action, key_handler_return)
+	main.window_main.bind(g.binding_up, key_handler_up)
+	main.window_main.bind(g.binding_down, key_handler_down)
+	main.window_main.bind(g.binding_left, key_handler_left)
+	main.window_main.bind(g.binding_right, key_handler_right)
+	main.window_main.bind(g.binding_inv, key_handler)
+	main.window_main.bind(g.binding_save, key_handler)
+	main.window_main.bind(g.binding_quit, key_handler)
 
 
 	canvas_buttons.bind("<ButtonRelease-1>", mouse_handler_click)
