@@ -5,7 +5,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.36. Released under the GPL. Copyright 2004
+#Dragon Hunt 3.37. Released under the GPL. Copyright 2004
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -39,10 +39,12 @@ exp = 0
 level = 0
 skillpoints = 1
 
-#stores attack/defense, adjusted by equipment.
-#kept correct by main.refreshmap(). Use for calculations.
+#stores attack/defense/hp/ep, adjusted by equipment.
+#kept correct by main.refreshmap(). Use these for calculations.
 adj_attack = 0
 adj_defense = 0
+adj_maxhp = 0
+adj_maxep = 0
 
 
 #default tile width. Set in variables.txt, or default to 32.
@@ -84,6 +86,20 @@ per_turn_script = []
 #to init tk.
 init_tk_already = 0
 
+#Default key bindings for the game.
+binding_up="<Up>"
+binding_down="<Down>"
+binding_left="<Left>"
+binding_right="<Right>"
+binding_action="<Return>"
+binding_cancel="<Escape>"
+binding_attack="a"
+binding_save="s"
+binding_quit="q"
+binding_inv="i"
+binding_inv_right="<Next>"
+binding_inv_left="<Prior>"
+
 #save the game in saves/input.
 #uses pickle, first line is a version number.
 def savegame(save_file):
@@ -219,6 +235,7 @@ def loadgame_31(save_file):
 
 #this calls scripting.py to read the datafiles.
 def init_data():
+	read_settings()
 	read_maps()
 	read_scripts()
 	item.read_items()
@@ -246,6 +263,59 @@ def read_game_name():
 #What dice to roll when starting a new game. 2d array.
 new_game_dice = []
 
+
+#get the key bindings from settings.txt
+def read_settings():
+	global binding_up
+	global binding_down
+	global binding_left
+	global binding_right
+	global binding_action
+	global binding_cancel
+	global binding_attack
+	global binding_save
+	global binding_quit
+	global binding_inv
+	global binding_inv_right
+	global binding_inv_left
+
+	#try to open settings.txt. If it doesn't exist,
+	# just use the default settings.
+	try: file = open("../settings.txt", 'r')
+	except IOError: return 0
+	line = file.readline()
+	while (line != ''):
+		line = line.strip()
+		if (line[:1] == "#" or line[:1] == ""):
+			line = file.readline()
+			continue
+		if (line.split("=", 1)[0].strip() == "up"):
+			binding_up = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "down"):
+			binding_down = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "left"):
+			binding_left = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "right"):
+			binding_right = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "action"):
+			binding_action = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "cancel"):
+			binding_cancel = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "attack"):
+			binding_attack = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "save"):
+			binding_save = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "quit"):
+			binding_quit = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "inv"):
+			binding_inv = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "inv_right"):
+			binding_inv_right = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "inv_left"):
+			binding_inv_left = line.split("=", 1)[1].strip()
+		line = file.readline()
+
+
 def read_variables():
 	for i in range(5):
 		new_game_dice.append([])
