@@ -182,37 +182,54 @@ def process_onload():
 
 #recalculate and display stats
 def recalc_stats():
-	#hp/ep bars
-	canvas_hp.delete("show_hp")
-	temp_width = g.hpbar_width*g.hp/g.maxhp
-	if temp_width < 0: temp_width=0
-	canvas_hp.create_rectangle(0, 0, temp_width,
-		g.hpbar_width/6, fill="#05BB05", tags="show_hp")
-	canvas_ep.delete("show_ep")
-	temp_width = g.hpbar_width*g.ep/g.maxep
-	if temp_width < 0: temp_width=0
-	canvas_ep.create_rectangle(0, 0, temp_width,
-		g.hpbar_width/6, fill="#0505EE", tags="show_ep")
-
-
-	hp.set(str(g.hp) + "/" + str(g.maxhp))
-	ep.set(str(g.ep) + "/" + str(g.maxep))
-	g.adj_attack = int(g.attack)
-
 	#adjust attack and defense based on equipment.
+	g.adj_attack = int(g.attack)
 	if g.item.equip[0] != -1:
 		g.adj_attack = g.adj_attack + g.item.item[g.item.equip[0]].quality
+	for i in range(6):
+		if g.item.equip[i] != -1:
+			g.adj_attack = g.adj_attack + g.item.item[g.item.equip[i]].attack_bonus
 	attack.set(g.adj_attack)
 
 	g.adj_defense = int(g.defense)
 	for i in range(1, 6):
 		if g.item.equip[i] != -1:
 			g.adj_defense = g.adj_defense + g.item.item[g.item.equip[i]].quality
+	for i in range(6):
+		if g.item.equip[i] != -1:
+			g.adj_defense = g.adj_defense + g.item.item[g.item.equip[i]].defense_bonus
 	defense.set(g.adj_defense)
+
 	gold.set(g.gold)
 	exp.set(g.exp)
 	level.set(g.level)
 
+	g.adj_maxhp = int(g.maxhp)
+	for i in range(6):
+		if g.item.equip[i] != -1:
+			g.adj_maxhp = g.adj_maxhp + g.item.item[g.item.equip[i]].hp_bonus
+	if g.hp > g.adj_maxhp: g.hp = g.adj_maxhp
+
+	g.adj_maxep = int(g.maxep)
+	for i in range(6):
+		if g.item.equip[i] != -1:
+			g.adj_maxep = g.adj_maxep + g.item.item[g.item.equip[i]].ep_bonus
+	if g.ep > g.adj_maxep: g.ep = g.adj_maxep
+
+	#hp/ep bars
+	canvas_hp.delete("show_hp")
+	temp_width = g.hpbar_width*g.hp/g.adj_maxhp
+	if temp_width < 0: temp_width=0
+	canvas_hp.create_rectangle(0, 0, temp_width,
+		g.hpbar_width/6, fill="#05BB05", tags="show_hp")
+	canvas_ep.delete("show_ep")
+	temp_width = g.hpbar_width*g.ep/g.adj_maxep
+	if temp_width < 0: temp_width=0
+	canvas_ep.create_rectangle(0, 0, temp_width,
+		g.hpbar_width/6, fill="#0505EE", tags="show_ep")
+	hp.set(str(g.hp) + "/" + str(g.adj_maxhp))
+	ep.set(str(g.ep) + "/" + str(g.adj_maxep))
+
 
 #Return an array of pictures that the given tile should display.
 #x and y are relative to the player.
@@ -401,7 +418,7 @@ def show_dialog(line=None):
 	canvas_map.create_image((mapsizex*tilesize/2),
 		(6*mapsizey*tilesize/7), image=begin_button_sel, anchor="n", tags="ok")
 	#bindings
-	window_main.bind("<Return>", activate_yesno)
+	window_main.bind(g.binding_action, activate_yesno)
 	canvas_map.tag_bind("ok", "<Button-1>", activate_yesno)
 	#wait. Continue after activate_yesno() is run.
 	window_main.wait_variable(return_from_yesno)
@@ -444,11 +461,11 @@ def show_yesno(line=""):
 	canvas_map.create_image((mapsizex*tilesize/2),
 		(6*mapsizey*tilesize/7), image=yes_button, anchor="nw", tags="yes")
 	#bindings
-	window_main.bind("<Up>", change_yesno_sel)
-	window_main.bind("<Right>", change_yesno_sel)
-	window_main.bind("<Left>", change_yesno_sel)
-	window_main.bind("<Down>", change_yesno_sel)
-	window_main.bind("<Return>", activate_yesno)
+	window_main.bind(g.binding_up, change_yesno_sel)
+	window_main.bind(g.binding_right, change_yesno_sel)
+	window_main.bind(g.binding_left, change_yesno_sel)
+	window_main.bind(g.binding_down, change_yesno_sel)
+	window_main.bind(g.binding_action, activate_yesno)
 	canvas_map.tag_bind("no", "<Enter>", change_yesno_to_no)
 	canvas_map.tag_bind("yes", "<Enter>", change_yesno_to_yes)
 	canvas_map.tag_bind("no", "<Button-1>", activate_yesno)
@@ -651,16 +668,16 @@ def do_nothing(event=0):
 #this binds keys to the appropriate commands. Needs to be called after
 #returning from various subwindows.
 def bind_keys():
-	window_main.bind("<Up>", move_north)
-	window_main.bind("<Right>", move_east)
-	window_main.bind("<Left>", move_west)
-	window_main.bind("<Down>", move_south)
-	window_main.bind("<Escape>", close_window)
-	window_main.bind("i", show_inv)
-	window_main.bind("a", do_nothing)
-	window_main.bind("s", save_game)
-	window_main.bind("q", close_window)
-	window_main.bind("<Return>", show_inv)
+	window_main.bind(g.binding_up, move_north)
+	window_main.bind(g.binding_right, move_east)
+	window_main.bind(g.binding_left, move_west)
+	window_main.bind(g.binding_down, move_south)
+	window_main.bind(g.binding_cancel, close_window)
+	window_main.bind(g.binding_inv, show_inv)
+	window_main.bind(g.binding_attack, do_nothing)
+	window_main.bind(g.binding_save, save_game)
+	window_main.bind(g.binding_quit, close_window)
+	window_main.bind(g.binding_action, show_inv)
 
 #handles mouse clicks on the main tile canvas.
 def mouse_handler(event=0):
